@@ -18,6 +18,7 @@ from execute import Execute
 from easygsettings import EasyGSettings
 from easyfiles import *
 import recentHelper as RecentHelper
+import pipes
 
 import matemenu
 
@@ -503,7 +504,6 @@ class pluginclass( object ):
         else:
             self.changeTab( 1 )
 
-        self.searchEntry.select_region( 0, -1 )
         if self.rememberFilter and self.searchEntry.get_text().strip() != "":
             self.Filter(self.activeFilter[2], self.activeFilter[1])
 
@@ -545,7 +545,7 @@ class pluginclass( object ):
         # of the existing text, that's the most likely candidate anyhow
         self.searchEntry.grab_focus()
         if self.rememberFilter or not clear:
-            self.searchEntry.set_position(-1)
+            self.searchEntry.select_region( 0, -1 )
         else:
             self.searchEntry.set_text("")
 
@@ -637,7 +637,7 @@ class pluginclass( object ):
             keywords = keyword.split(" ")
             command = "cat %(home)s/.linuxmint/mintMenu/apt.cache" % {'home':home}
             for word in keywords:
-                command = "%(command)s | grep %(word)s" % {'command':command, 'word':word}
+                command = "%(command)s | grep %(word)s" % {'command':command, 'word':pipes.quote(word)}
             pkgs = commands.getoutput(command)
             pkgs = pkgs.split("\n")
             num_pkg_found = 0
